# -*- coding: utf-8 -*-
"""
This is a cx_Freeze setup.py script

Usage:
    python cxFreeze_setup.py build
"""
import sys
import os
from cx_Freeze import setup, Executable


# Dependencies are automatically detected, but it might need fine tuning.
APPLICATION = 'QuickIR'
VERSION = '1.0.9'

if sys.platform == 'win32':
    python_dir = r'C:\Python35'    # Python installed directory
    include_files = [
        python_dir + r'\DLLs\tcl86t.dll',
        python_dir + r'\DLLs\tk86t.dll',
        'images'
    ]
elif sys.platform == 'darwin':
    include_files = [
        ('/Library/Frameworks/Tcl.framework/Resources/Scripts', 'tcl8.5'),
        ('/Library/Frameworks/Tk.framework/Resources/Scripts', 'tk8.5'),
        'images'
    ]
else:
    include_files = []

includes = ['irkit', 'resolve_irkit']
pakages = ['os', 'sys', 'tkinter', 'pybonjour']
excludes = ['logging', 'distutils',
            'multiprocessing', 'pydoc_data',
            'test', 'unittest',
            'xml', 'xmlrpc']
build_exe_options = {'includes': includes,
                     'include_files': include_files,
                     'packages': pakages,
                     'excludes': excludes,
                     'optimize': 2}

bdist_mac_options = {'bundle_name': APPLICATION,
                     'iconfile': 'app.icns',
                     'custom_info_plist': 'Info.plist',
                     'include_frameworks': []}

base = None
if sys.platform == 'win32':
    base = 'Win32GUI'
    os.environ['TCL_LIBRARY'] = python_dir + r'\tcl\tcl8.6'
    os.environ['TK_LIBRARY'] = python_dir + r'\tcl\tk8.6'
    exe = [
        Executable(script='QuickIR.py',
                   base=base,
                   targetName='QuickIR.exe',
                   icon='app.ico')
    ]
else:
    exe = [
        Executable(script='QuickIR.py',
                   base=base,
                   targetName=APPLICATION)
    ]


setup(name=APPLICATION,
      version=VERSION,
      description='QuickIR IRKit controller',
      options={
          'build_exe': build_exe_options,
          'bdist_mac': bdist_mac_options
      },
      executables=exe)
